@@ -805,12 +805,8 @@ final class DispatchingEmitter implements Emitter
      * @throws NoTestCaseObjectOnCallStackException
      * @throws UnknownEventTypeException
      */
-    public function testTriggeredPhpunitNotice(?Code\Test $test, string $message): void
+    public function testTriggeredPhpunitNotice(Code\Test $test, string $message): void
     {
-        if ($test === null) {
-            $test = TestMethodBuilder::fromCallStack();
-        }
-
         $this->dispatcher->dispatch(
             new Test\PhpunitNoticeTriggered(
                 $this->telemetryInfo(),
