@@ -11,21 +11,20 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-final class AnnotationFilterTest extends TestCase
+class AlternativeSuffixTest extends TestCase
 {
-    /**
-     * @covers \PHPUnit\TestFixture\AnnotationFilter
-     */
     public function testOne(): void
     {
         $this->assertTrue(true);
     }
 
-    /**
-     * @uses \PHPUnit\TestFixture\AnnotationFilter
-     */
     public function testTwo(): void
     {
         $this->assertTrue(true);
     }
+
+    public function testThree(): void
+    {
+        $this->assertTrue(true);
+    }
 }
